#!/bin/bash
# © Copyright [2018 - 2020, 2024] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

# Log files
DATE_NOW=$(date "+%Y-%m-%d %H:%M:%S")
FILE_NAME="activate_cis.sh"
LOG_FILE="/var/opt/novell/log/cis/firewallchange.log"

if [ $# -eq 0 ]
then
        /sbin/sysctl --system 2>&1 > /dev/null

        firewallstate=$(firewall-cmd --state 2>&1)
        echo "$DATE_NOW - firewall is $firewallstate - $FILE_NAME" >> "$LOG_FILE"
        if [ "$firewallstate" == "running" ]; then
                DEFAULT_ZONE=`firewall-cmd --get-default-zone`
                echo "$DATE_NOW - firewall default zone is $DEFAULT_ZONE - $FILE_NAME" >> "$LOG_FILE"
                for port in 8343 8344 3306; do
                        firewallop=$(firewall-cmd --permanent --zone=$DEFAULT_ZONE --query-port=${port}/tcp) > /dev/null 2>&1
                        echo "$DATE_NOW - firewall port:${port}/tcp is added: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                        if [ "$firewallop" != "yes" ]; then
                                firewallop=$(firewall-cmd --permanent --zone=$DEFAULT_ZONE --add-port=${port}/tcp) > /dev/null 2>&1
                                echo "$DATE_NOW - adding firewall port:${port}/tcp: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                                if [ "$firewallop" != "success" ]; then

                                        >&2 echo "Failed to add cis ports in firewall" >> "$LOG_FILE"
                                        exit 1;
                                fi
                        fi
                done
                
                firewall-cmd --reload > /dev/null 2>&1
                if [ $? -ne 0 ]; then
                        >&2 echo "Firewall failed to reload" >> "$LOG_FILE"
                        exit 1;
                fi
        else
                DEFAULT_ZONE=`firewall-offline-cmd --get-default-zone`
                echo "$DATE_NOW - firewall default zone is $DEFAULT_ZONE - $FILE_NAME" >> "$LOG_FILE"
                for port in 8343 8344 3306; do
                        firewallop=$(firewall-offline-cmd --zone=$DEFAULT_ZONE --query-port=${port}/tcp) > /dev/null 2>&1
                        echo "$DATE_NOW - firewall offline port:${port}/tcp is added: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                        if [ "$firewallop" != "yes" ]; then
                                firewallop=$(firewall-offline-cmd --zone=$DEFAULT_ZONE --add-port=${port}/tcp) > /dev/null 2>&1
                                echo "$DATE_NOW - adding firewall offline port:${port}/tcp: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                                if [ "$firewallop" != "success" ]; then
                                        >&2 echo "Failed to add cis ports in firewall offline" >> "$LOG_FILE"
                                        exit 1;
                                fi
                        fi
                done
        fi

elif [ $# -eq 1 -a $1 = "--cleanup" ]
then
        docker network rm cisnet 2>/dev/null
fi