#!/bin/bash
# © Copyright [2024] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

/sbin/sysctl --system 2>&1 > /dev/null
if [ $# -eq 1 ]
then
    subnetIP=$1
else
    logger -t "No subnetIP provided"
    exit 1
fi
IP=${subnetIP/\/*/}
IFS="."
set -- $IP
range=$((0x$(printf "%02x%02x%02x%02x\n" $1 $2 $3 $4)))
set -- $IP
g=$4+1
v=$((range|g))
gatewayIP=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))

conf="/etc/opt/novell/cis/config"

setdockerIPinConfigFile() {
    subnet=$(docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" cisnet)
    if [ $? -ne 0 ]; then
        logger -t cis "Unable to get cisnet subnet."
        exit 1;
    fi

    gateway=$(docker network inspect -f "{{(index (.IPAM.Config) 0).Gateway}}" cisnet)
    if [ $? -ne 0 ]; then
        logger -t cis "Unable to get cisnet gateway."
        exit 1;
    fi

    sub=${subnet/\/*/}
    mask=$((1<<(32-${subnet/*\//})))

    IFS="."
    set -- $sub
    range=$((0x$(printf "%02x%02x%02x%02x\n" $1 $2 $3 $4)))
    set -- $gateway
    g=$4

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_DATA/ c\IP_DATA="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_METADATA/ c\IP_METADATA="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_POLICY/ c\IP_POLICY="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_AUTH/ c\IP_AUTH="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_MGMT/ c\IP_MGMT="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_COLLECTOR/ c\IP_COLLECTOR="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_AGGREGATOR/ c\IP_AGGREGATOR="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_REPCOLLECTOR/ c\IP_REPCOLLECTOR="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_REPAGGREGATOR/ c\IP_REPAGGREGATOR="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_GATEWAY/ c\IP_GATEWAY="'"$ip"'"' $conf

    g=$g+1
    v=$((range|g))
    ip=$(printf "%d.%d.%d.%d" $(((v >> 24) & 255)) $(((v >> 16) & 255)) $(((v >> 8) & 255)) $(((v) & 255)))
    sed -i '/IP_DASHBOARD/ c\IP_DASHBOARD="'"$ip"'"' $conf
}

IP=$(docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" cisnet 2>/dev/null) 
if [ $? -eq 0 ]; then
    if [ "$IP" != "$subnetIP" ]; then
        logger -t cis "cisnet already configured, reconfiguring it."
        docker network rm cisnet 2>&1 > /dev/null
        if [ $? -ne 0 ]; then
            logger -t cis "Docker network deletion failed.\n"
            exit 1
        fi
    fi
fi

docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" cisnet 2>/dev/null
if [ $? -ne 0 ]; then
    docker network create --driver=bridge --subnet="$subnetIP" --gateway="$gatewayIP" cisnet 2>&1 > /dev/null
    if [ $? -ne 0 ]; then
        logger -t cis "Docker network create failed.\n"
        exit 1
    fi
    setdockerIPinConfigFile

    systemctl restart docker
    if [ $? -ne 0 ]; then
        logger -t cis "Docker is not running.\n"
        exit 1;
    fi
    cat $conf | grep CIS_SUBNET > /dev/null 2>&1
    if [ $? -eq 1 ]; then
        echo "CIS_SUBNET=\"\"" >> $conf
    fi
    sed -i '/CIS_SUBNET/ c\CIS_SUBNET="'"$subnetIP"'"' $conf
fi
