#!/bin/sh

group_name="cisgroup"

function usage()
{       
        echo "Usage :"
        echo "./cis_enable_lum_user.sh -a <admin_context> -x <group_context> -v <media volume> -t <tree name>"
        echo "-a - Admin dn in ldap format (eg. cn=admin,o=microfocus)."
        echo "-x - Group context (eg. o=microfocus)."
        echo "-v - Media volume name. "
        echo "-t - Tree name. "
        echo " e.g ./cis_enable_lum_user.sh -a cn=admin,o=microfocus -x o=microfocus -v CISVOL -t OESTREE"
        exit 
}

log_file="/var/opt/novell/log/cis/cis_enable_lum_user.log"

# write_to_log function will redirect logs on log file and print on terminal also.
function write_to_log() {
  echo "$@" 
  echo  "$(date) $@"  >> ${log_file} 
}

# print_log fuction will redirect logs to log file.
function print_log()
{
if [ "$1" != "" ]; then
  echo  "$(date) $1"  >> ${log_file} 
fi
}


workstation_name=""
workstation_name=$(hostname);


if [ $? -ne 0 ] || [ "$workstation_name" = "" ]; then
  write_to_log "Failed to get Hostname." 
  exit
fi
  
ADMIN=false;
CONTEXT=false;
VOL=false;
TREE=false;

while getopts "a:x:v:t:-help:h" opt; do
	case "${opt}" in
    a)ADMIN=true
      adminFDN=${OPTARG};;
		x)CONTEXT=true
      group_context=${OPTARG};;  
    v)VOL=true
      vol=${OPTARG};;
    t)TREE=true
      tree=${OPTARG};;
    h)usage;;  
    -help)usage;;
    *) usage;;
  esac
done

if [ "$ADMIN" = false ] ||  [ "$CONTEXT" = false ] || [ "$VOL" = false ] ||  [ "$TREE" = false ]; then
	write_to_log "Failed Some arguments are missing."
	usage
fi   
 
cat /etc/passwd | grep "cisuser" > /dev/null
if [ $? -eq 0 ]; then
  log=$(userdel cisuser 2>&1)
  print_log "$log" 
  if [ $? -ne 0 ]; then
    write_to_log "Failed to delete user due to error."
    exit 1
  fi
fi   
 
cat /etc/group | grep "cisgroup" > /dev/null
if [ $? -eq 0 ]; then
  log=$(groupdel cisgroup)
  print_log "$log"
  if [ $? -ne 0 ]; then
    write_to_log "Failed to delete group due to error."
    exit 1
  fi
fi

write_to_log "Adding CIS group " 
log=$(namgroupadd -a $adminFDN -x $group_context -W $workstation_name $group_name) 
if [ $? -eq 0 ]; then
  write_to_log "Group added successfully"
else
  write_to_log "$log"
fi 

write_to_log "Adding CIS User " 
log=$(namuseradd -a $adminFDN -x $group_context -c cisuser  -g cn=cisgroup,$group_context -s /sbin/nologin cisuser)   
if [ $? -eq 0 ]; then
  write_to_log "User added successfully"
elif [ $? -eq 1 ]; then
  echo "User with same name exists"
else
  echo "Failed to create cisuser"
fi
print_log "$log"

log=$(namuserlist cisuser)
print_log "$log"
log=$(rcnamcd restart) 
print_log "$log"
log=$(rcnscd restart) 
print_log "$log"
 
if [ "$VOL" = true ] && [ "$TREE" = true ]; then
  str=$(echo $group_context| cut -d'=' -f 2)
  log=$(rights -f /media/nss/$vol -r rwfcem trustee cisuser.$str.$tree 2>&1 )
  if [ "$log" = "" ]; then
    write_to_log "Rights assigned on $vol"
  else
    write_to_log "$log"
  fi
fi

