#!/bin/bash
# © Copyright [2024] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

source  /etc/opt/novell/cis/config > /dev/null 2>&1
if [ $? -ne 0 ]; then
    echo "CIS Configuration file not found"
    exit 1
fi
SUB=$(docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" cisnet 2>/dev/null)
if [ $? -eq 0 ]; then
    if [ "$CIS_SUBNET" == "$SUB" ]; then
        exit 0
    elif [ "$CIS_SUBNET" == "" ]; then
        cat /etc/opt/novell/cis/config | grep CIS_SUBNET > /dev/null 2>&1
        if [ $? -eq 1 ]; then
            echo "CIS_SUBNET=\"\"" >> /etc/opt/novell/cis/config
        fi
        echo "CIS subnet entry is empty in conf file, configuring cisnet with $SUB"
        sed -i '/CIS_SUBNET/ c\CIS_SUBNET="'"$SUB"'"' /etc/opt/novell/cis/config
   elif [ "$CIS_SUBNET" != "$SUB" ]; then
        docker network rm cisnet > /dev/null 2>&1 
        if [ $? -ne 0 ]; then
            echo "Not able to delete cisnet"
            exit 1
        fi
 
        /opt/novell/cis/bin/activate_cis_network.sh $CIS_SUBNET
        if [ $? -ne 0 ]; then
            echo "Failed to create cisnet with $CIS_SUBNET"
            exit 1
        fi
    fi
else
    if [ "$CIS_SUBNET" == "" ]; then
        echo "Configuring cisnet with defult IP"
        /opt/novell/cis/bin/activate_cis_network.sh "172.16.0.0/16"
        if [ $? -ne 0 ]; then
            echo "Failed to create cisnet with default IP"
            exit 1
        fi
    else
        echo "Configuring cisnet with $CIS_SUBNET"
        /opt/novell/cis/bin/activate_cis_network.sh $CIS_SUBNET
        if [ $? -ne 0 ]; then
            echo "Failed to create cisnet with $CIS_SUBNET subnet"
            exit 1
        fi
    fi
fi
